@@ -14,8 +14,6 @@ import (
 )
 
 const (
-	nsMUC          = "http://jabber.org/protocol/muc"
-	nsMUCUser      = "http://jabber.org/protocol/muc#user"
 	NoHistory      = 0
 	CharHistory    = 1
 	StanzaHistory  = 2
@@ -25,10 +23,6 @@ const (
 
 // Send sends room topic wrapped inside an XMPP message stanza body.
 func (c *Client) SendTopic(chat Chat) (n int, err error) {
-	// Reset ticker for periodic pings if configured.
-	if c.periodicPings {
-		c.periodicPingTicker.Reset(c.periodicPingPeriod)
-	}
 	return fmt.Fprintf(c.stanzaWriter, "<message to='%s' type='%s' xml:lang='en'>"+"<subject>%s</subject></message>\n",
 		xmlEscape(chat.Remote), xmlEscape(chat.Type), xmlEscape(chat.Text))
 }
@@ -37,15 +31,11 @@ func (c *Client) JoinMUCNoHistory(jid, nick string) (n int, err error) {
 	if nick == "" {
 		nick = c.jid
 	}
-	// Reset ticker for periodic pings if configured.
-	if c.periodicPings {
-		c.periodicPingTicker.Reset(c.periodicPingPeriod)
-	}
 	return fmt.Fprintf(c.stanzaWriter, "<presence to='%s/%s'>"+
 		"<x xmlns='%s'>"+
 		"<history maxchars='0'/></x>"+
 		"</presence>\n",
-		xmlEscape(jid), xmlEscape(nick), nsMUC)
+		xmlEscape(jid), xmlEscape(nick), XMPPNS_MUC)
 }
 
 // xep-0045 7.2
@@ -55,55 +45,35 @@ func (c *Client) JoinMUC(jid, nick string, history_type, history int, history_da
 	}
 	switch history_type {
 	case NoHistory:
-		// Reset ticker for periodic pings if configured.
-		if c.periodicPings {
-			c.periodicPingTicker.Reset(c.periodicPingPeriod)
-		}
 		return fmt.Fprintf(c.stanzaWriter, "<presence to='%s/%s'>"+
 			"<x xmlns='%s' />"+
 			"</presence>\n",
-			xmlEscape(jid), xmlEscape(nick), nsMUC)
+			xmlEscape(jid), xmlEscape(nick), XMPPNS_MUC)
 	case CharHistory:
-		// Reset ticker for periodic pings if configured.
-		if c.periodicPings {
-			c.periodicPingTicker.Reset(c.periodicPingPeriod)
-		}
 		return fmt.Fprintf(c.stanzaWriter, "<presence to='%s/%s'>"+
 			"<x xmlns='%s'>"+
 			"<history maxchars='%d'/></x>"+
 			"</presence>\n",
-			xmlEscape(jid), xmlEscape(nick), nsMUC, history)
+			xmlEscape(jid), xmlEscape(nick), XMPPNS_MUC, history)
 	case StanzaHistory:
-		// Reset ticker for periodic pings if configured.
-		if c.periodicPings {
-			c.periodicPingTicker.Reset(c.periodicPingPeriod)
-		}
 		return fmt.Fprintf(c.stanzaWriter, "<presence to='%s/%s'>"+
 			"<x xmlns='%s'>"+
 			"<history maxstanzas='%d'/></x>"+
 			"</presence>\n",
-			xmlEscape(jid), xmlEscape(nick), nsMUC, history)
+			xmlEscape(jid), xmlEscape(nick), XMPPNS_MUC, history)
 	case SecondsHistory:
-		// Reset ticker for periodic pings if configured.
-		if c.periodicPings {
-			c.periodicPingTicker.Reset(c.periodicPingPeriod)
-		}
 		return fmt.Fprintf(c.stanzaWriter, "<presence to='%s/%s'>"+
 			"<x xmlns='%s'>"+
 			"<history seconds='%d'/></x>"+
 			"</presence>\n",
-			xmlEscape(jid), xmlEscape(nick), nsMUC, history)
+			xmlEscape(jid), xmlEscape(nick), XMPPNS_MUC, history)
 	case SinceHistory:
 		if history_date != nil {
-			// Reset ticker for periodic pings if configured.
-			if c.periodicPings {
-				c.periodicPingTicker.Reset(c.periodicPingPeriod)
-			}
 			return fmt.Fprintf(c.stanzaWriter, "<presence to='%s/%s'>"+
 				"<x xmlns='%s'>"+
 				"<history since='%s'/></x>"+
 				"</presence>\n",
-				xmlEscape(jid), xmlEscape(nick), nsMUC, history_date.Format(time.RFC3339))
+				xmlEscape(jid), xmlEscape(nick), XMPPNS_MUC, history_date.Format(time.RFC3339))
 		}
 	}
 	return 0, errors.New("unknown history option")
@@ -116,61 +86,41 @@ func (c *Client) JoinProtectedMUC(jid, nick string, password string, history_typ
 	}
 	switch history_type {
 	case NoHistory:
-		// Reset ticker for periodic pings if configured.
-		if c.periodicPings {
-			c.periodicPingTicker.Reset(c.periodicPingPeriod)
-		}
 		return fmt.Fprintf(c.stanzaWriter, "<presence to='%s/%s'>"+
 			"<x xmlns='%s'>"+
 			"<password>%s</password>"+
 			"</x>"+
 			"</presence>\n",
-			xmlEscape(jid), xmlEscape(nick), nsMUC, xmlEscape(password))
+			xmlEscape(jid), xmlEscape(nick), XMPPNS_MUC, xmlEscape(password))
 	case CharHistory:
-		// Reset ticker for periodic pings if configured.
-		if c.periodicPings {
-			c.periodicPingTicker.Reset(c.periodicPingPeriod)
-		}
 		return fmt.Fprintf(c.stanzaWriter, "<presence to='%s/%s'>"+
 			"<x xmlns='%s'>"+
 			"<password>%s</password>"+
 			"<history maxchars='%d'/></x>"+
 			"</presence>\n",
-			xmlEscape(jid), xmlEscape(nick), nsMUC, xmlEscape(password), history)
+			xmlEscape(jid), xmlEscape(nick), XMPPNS_MUC, xmlEscape(password), history)
 	case StanzaHistory:
-		// Reset ticker for periodic pings if configured.
-		if c.periodicPings {
-			c.periodicPingTicker.Reset(c.periodicPingPeriod)
-		}
 		return fmt.Fprintf(c.stanzaWriter, "<presence to='%s/%s'>"+
 			"<x xmlns='%s'>"+
 			"<password>%s</password>"+
 			"<history maxstanzas='%d'/></x>"+
 			"</presence>\n",
-			xmlEscape(jid), xmlEscape(nick), nsMUC, xmlEscape(password), history)
+			xmlEscape(jid), xmlEscape(nick), XMPPNS_MUC, xmlEscape(password), history)
 	case SecondsHistory:
-		// Reset ticker for periodic pings if configured.
-		if c.periodicPings {
-			c.periodicPingTicker.Reset(c.periodicPingPeriod)
-		}
 		return fmt.Fprintf(c.stanzaWriter, "<presence to='%s/%s'>"+
 			"<x xmlns='%s'>"+
 			"<password>%s</password>"+
 			"<history seconds='%d'/></x>"+
 			"</presence>\n",
-			xmlEscape(jid), xmlEscape(nick), nsMUC, xmlEscape(password), history)
+			xmlEscape(jid), xmlEscape(nick), XMPPNS_MUC, xmlEscape(password), history)
 	case SinceHistory:
 		if history_date != nil {
-			// Reset ticker for periodic pings if configured.
-			if c.periodicPings {
-				c.periodicPingTicker.Reset(c.periodicPingPeriod)
-			}
 			return fmt.Fprintf(c.stanzaWriter, "<presence to='%s/%s'>"+
 				"<x xmlns='%s'>"+
 				"<password>%s</password>"+
 				"<history since='%s'/></x>"+
 				"</presence>\n",
-				xmlEscape(jid), xmlEscape(nick), nsMUC, xmlEscape(password), history_date.Format(time.RFC3339))
+				xmlEscape(jid), xmlEscape(nick), XMPPNS_MUC, xmlEscape(password), history_date.Format(time.RFC3339))
 		}
 	}
 	return 0, errors.New("unknown history option")
@@ -178,10 +128,6 @@ func (c *Client) JoinProtectedMUC(jid, nick string, password string, history_typ
 
 // xep-0045 7.14
 func (c *Client) LeaveMUC(jid string) (n int, err error) {
-	// Reset ticker for periodic pings if configured.
-	if c.periodicPings {
-		c.periodicPingTicker.Reset(c.periodicPingPeriod)
-	}
 	return fmt.Fprintf(c.stanzaWriter, "<presence from='%s' to='%s' type='unavailable' />\n",
 		c.jid, xmlEscape(jid))
 }
