@@ -5,11 +5,6 @@ import (
 	"fmt"
 )
 
-const (
-	XMPPNS_PUBSUB       = "http://jabber.org/protocol/pubsub"
-	XMPPNS_PUBSUB_EVENT = "http://jabber.org/protocol/pubsub#event"
-)
-
 type clientPubsubItem struct {
 	XMLName xml.Name `xml:"item"`
 	ID      string   `xml:"id,attr"`
@@ -102,7 +97,7 @@ func pubsubUnsubscriptionStanza(node, jid string) string {
 }
 
 func (c *Client) PubsubSubscribeNode(node, jid string) error {
-	id := getUUIDv4()
+	id := getUUID()
 	c.subIDs = append(c.subIDs, id)
 	_, err := c.RawInformation(c.jid,
 		jid,
@@ -113,7 +108,7 @@ func (c *Client) PubsubSubscribeNode(node, jid string) error {
 }
 
 func (c *Client) PubsubUnsubscribeNode(node, jid string) error {
-	id := getUUIDv4()
+	id := getUUID()
 	c.unsubIDs = append(c.unsubIDs, id)
 	_, err := c.RawInformation(c.jid,
 		jid,
@@ -124,7 +119,7 @@ func (c *Client) PubsubUnsubscribeNode(node, jid string) error {
 }
 
 func (c *Client) PubsubRequestLastItems(node, jid string) error {
-	id := getUUIDv4()
+	id := getUUID()
 	c.itemsIDs = append(c.itemsIDs, id)
 	body := fmt.Sprintf("<items node='%s'/>", node)
 	_, err := c.RawInformation(c.jid, jid, id, "get", pubsubStanza(body))
@@ -132,7 +127,7 @@ func (c *Client) PubsubRequestLastItems(node, jid string) error {
 }
 
 func (c *Client) PubsubRequestItem(node, jid, id string) error {
-	stanzaID := getUUIDv4()
+	stanzaID := getUUID()
 	c.itemsIDs = append(c.itemsIDs, stanzaID)
 	body := fmt.Sprintf("<items node='%s'><item id='%s'/></items>", node, id)
 	_, err := c.RawInformation(c.jid, jid, stanzaID, "get", pubsubStanza(body))
